#========================================================================================
# package      DE_EPAGES::GoogleAdWords::API::AppStoreCleverGoogleAds
# state        public
# description  Functions related to CleverGoogleAds's App.
#========================================================================================
package DE_EPAGES::GoogleAdWords::API::AppStoreCleverGoogleAds;

use strict;

use DE_EPAGES::AppStore::API::Object::AppsClient;
use DE_EPAGES::Core::API::TestParameter qw ( TestObject );
use DE_EPAGES::GoogleAdWords::API::Constants qw (
    CLEVER_GOOGLE_ADS_DOMAIN
);

#========================================================================================
# function     new
# state        public
#----------------------------------------------------------------------------------------
# syntax       $AppStoreCleverGoogleAds = DE_EPAGES::GoogleAdWords::API::AppStoreCleverGoogleAds->new( );
#----------------------------------------------------------------------------------------
# description  AppStoreCleverGoogleAds constructor
#----------------------------------------------------------------------------------------
# return       $AppStoreCleverGoogleAds | AppStoreCleverGoogleAds object | object
#========================================================================================
sub new {
    my $class = shift;

    my $self = bless {}, $class;

    return $self;
}

#========================================================================================
# function     getCleverGoogleAdsAppID
# state        private
#----------------------------------------------------------------------------------------
# syntax       getCleverGoogleAdsAppID( $Shop );
#----------------------------------------------------------------------------------------
# description  Obtains CleverGoogleAds App ID.
#----------------------------------------------------------------------------------------
# input        $Shop | Shop. | object
# return       $appId | CleverGoogleAds App ID or undef if it isn't installed. | String
#========================================================================================
sub getCleverGoogleAdsAppID {
    my $self = shift;
    my ($Shop) = @_;

    $self->_TestObject( 'Shop', $Shop, 'DE_EPAGES::Shop::API::Object::Shop' );
    my $hShopParams = {
        'ShopType' => $Shop->get('ShopTypeRef')->alias(),
        'Shop'     => $Shop
    };

    my $AppsClient = $self->_createAppsClient($hShopParams);

    return $self->_findAppIdByUrl($AppsClient);
}

#----------------------------------------------------------------------------------------
# Wrappers
#========================================================================================
# function     _createAppsClient
# state        private
#----------------------------------------------------------------------------------------
# syntax       _createAppsClient( $hShopParams );
#----------------------------------------------------------------------------------------
# description  Wrapper to create an instance of AppsClient.
#----------------------------------------------------------------------------------------
# input        $hShopParams | Shop and ShopType.                            | object
# return       $appId       | CleverGoogleAds App ID or undef if it isn't installed. | String
#========================================================================================
sub _createAppsClient {
    my $self = shift;

    my ($hShopParams) = @_;

    my $AppsClient = DE_EPAGES::AppStore::API::Object::AppsClient->create($hShopParams);
    $self->_TestObject( 'AppsClient', $AppsClient, 'DE_EPAGES::AppStore::API::Object::AppsClient' );

    return $AppsClient;
}

#----------------------------------------------------------------------------------------
sub _TestObject {
    my $self = shift;

    my ( $Name, $Value, $ClassPackage ) = @_;

    TestObject( $Name, $Value, $ClassPackage );
}

#----------------------------------------------------------------------------------------
sub _findAppIdByUrl {
    my $self = shift;
    my ($AppsClient) = @_;

    return $AppsClient->findAppIdByUrl( 'APP_OAUTH2', CLEVER_GOOGLE_ADS_DOMAIN );;
}

#----------------------------------------------------------------------------------------

1;
