#========================================================================================
# package      DE_EPAGES::GoogleAdWords::API::TLE::CleverGoogleAdsAppID
# state        public
# base         DE_EPAGES::GoogleAdWords::API::TLE::TLEHandler
#----------------------------------------------------------------------------------------
# description  TLE for Getting CleverGoogleAds Backoffice URL
#========================================================================================
package DE_EPAGES::GoogleAdWords::API::TLE::CleverGoogleAdsAppID;

use DE_EPAGES::GoogleAdWords::API::Tools;
use base DE_EPAGES::GoogleAdWords::API::TLE::TLEHandler;
use strict;

use constant TLE_FUNCTION_NAME => 'CLEVER_GOOGLE_ADS_APP_ID';

#========================================================================================
# function     RegisterHandlerProc
# state        public
#----------------------------------------------------------------------------------------
# syntax       $RegisterHandlerProc( $hParams );
#----------------------------------------------------------------------------------------
# description  this function register this attribute handle on the processor via hook
#               function on hook TLEProcessorRegistration
#----------------------------------------------------------------------------------------
# input        $hParams | hook arguments keys :
#               <ul>
#                   <li>Processor - tle processor - object
#               </ul> | ref.hash
#========================================================================================
sub RegisterHandlerProc {
    my ($Params) = @_;

    __PACKAGE__->new()->register( $Params->{'Processor'}, TLE_FUNCTION_NAME );

    return;
}

#========================================================================================
# function     CLEVER_GOOGLE_ADS_APP_ID
# state        public
#----------------------------------------------------------------------------------------
# syntax       $CleverGoogleAdsAppID = CLEVER_GOOGLE_ADS_APP_ID( $Processor, $aParams );
#----------------------------------------------------------------------------------------
# description  Finds out whether CleverGoogleAds app is avilable or not.
#----------------------------------------------------------------------------------------
# input        $Processor | tle processor | object
# input        $aParams | List of Parameters | array ref
# return       $CleverGoogleAdsAppID | Whether app is installed or not | boolean
#========================================================================================
sub CLEVER_GOOGLE_ADS_APP_ID {
    my $self = shift;
    my ( $Processor, $aParams ) = @_;

    my $Tools = DE_EPAGES::GoogleAdWords::API::Tools->new();
    my $Shop  = $self->getShop($aParams);

    return $Tools->CleverGoogleAdsAppID($Shop);
}

1;
