#========================================================================================
# package      DE_EPAGES::GoogleAdWords::API::TLE::TLEHandler
# state        public
#----------------------------------------------------------------------------------------
# description  This class contains common methods for TLE functions.
#========================================================================================
package DE_EPAGES::GoogleAdWords::API::TLE::TLEHandler;

use DE_EPAGES::Core::API::Log qw ( GetLog );
use DE_EPAGES::Object::API::Factory qw ( LoadObject );

use strict;

#========================================================================================
# function     RegisterHandlerProc
# state        private
#----------------------------------------------------------------------------------------
# syntax       $RegisterHandlerProc( $hParams );
#----------------------------------------------------------------------------------------
# description  this function register this attribute handle on the processor via hook
#               function on hook TLEProcessorRegistration
#----------------------------------------------------------------------------------------
# input        $hParams         | hook arguments keys :
#               <ul>
#                   <li>Processor - tle processor - object
#               </ul> | ref.hash
# input        $TLEFunctionName | TLE function name | String
#========================================================================================
sub RegisterHandlerProc {
    my ($Params, $TLEFunctionName) = @_;

    __PACKAGE__->new()->register( $Params->{'Processor'}, $TLEFunctionName );

    return;
}

#========================================================================================
# function     new
# state        private
#----------------------------------------------------------------------------------------
# syntax       $Handler = new DE_EPAGES::Object::API::TLE::IncludeTemplateHandler;
# example      my $PrefixHandler  = new DE_EPAGES::Object::API::TLE::IncludeTemplateHandler;
#----------------------------------------------------------------------------------------
# description  create a new handler
#----------------------------------------------------------------------------------------
# input        %args | args | array
#----------------------------------------------------------------------------------------
# return       $Handler | blessed object | object
#========================================================================================
sub new {
    my $class = shift;
    my %args  = @_;

    my $self  = bless \%args, $class;

    return $self;
}

#========================================================================================
# function     register
# state        private
#----------------------------------------------------------------------------------------
# syntax       $Handler->register( $Processor, $TLEFunctionName );
#----------------------------------------------------------------------------------------
# description  Registers this handle on the processor
#----------------------------------------------------------------------------------------
# input        $Processor       | tle processor     | object
# input        $TLEFunctionName | TLE Function Name | string
#========================================================================================
sub register {
    my $self = shift;
    my ($Processor, $TLEFunctionName) = @_;

    GetLog->debug( "$TLEFunctionName.register" );
    $Processor->registerHandler( 'FunctionHandler', $self, $TLEFunctionName );

    return;
}

#---------------------------------------------------------------------------
#  Private methods
#---------------------------------------------------------------------------
sub getShop {
    my $self = shift;
    my ($aParams) = @_;

    return $self->_LoadObject(@{$aParams});
}

#---------------------------------------------------------------------------
#  Wrappers
#---------------------------------------------------------------------------
sub _LoadObject {
    my $self = shift;
    my ( $ObjectId ) = @_;

    return LoadObject($ObjectId);
}

1;
