#========================================================================================
# package      DE_EPAGES::Janolaw::API::Mail
# state        public
#----------------------------------------------------------------------------------------
# description  This package provides the janolaw email functions.
#========================================================================================
package DE_EPAGES::Janolaw::API::Mail;
use base Exporter;
use strict;

our @EXPORT_OK = qw ( SendJanolawErrorMail );

use DE_EPAGES::Object::API::Table::Language qw( GetInfoLanguage );
use DE_EPAGES::Object::API::Table::Locale       qw( GetInfoLocale );
use DE_EPAGES::Core::API::TestParameter qw ( TestObject );
use DE_EPAGES::Core::API::Log qw ( GetLog LogDebug );
use DE_EPAGES::Shop::API::Url qw ( BuildShopUrl );
use DE_EPAGES::Janolaw::API::Tools qw (JanolawLog);

#========================================================================================
# function     SendJanolawErrorMail
# state        public
#----------------------------------------------------------------------------------------
# syntax       SendJanolawErrorMail();
#----------------------------------------------------------------------------------------
# description  Sends off email if the t-pay configuration breeds an error.
# input        MailType | the mail type object | object
# input        Shop | the shop object | object
# return       success | 1 if success | int
#========================================================================================
sub SendJanolawErrorMail {
    my ($MailType, $Shop ) = @_;

    LogDebug('SendJanolawErrorMail', '1');
    TestObject( 'MailType', $MailType );
    TestObject( 'Shop', $Shop );

    my $hMailParams = {};

    #Create Mail
    my $Admin = $Shop->get('SuperMerchant');

    my $Email = $Admin->get('EMail') ? $Admin->get('EMail') : $Shop->get('MailFrom');

    JanolawLog('Email', $Email, 'SendJanolawErrorMail');

    $hMailParams->{'TO'} = $Email;
    $hMailParams->{'FROM'} = $Email;
    $hMailParams->{'HTMLAllowed'} = $Admin->get('IsHtmlEMailAllowed');
    $hMailParams->{'Subject'} = 'Ihr janolaw-Konto / Your janolaw account';

    LogDebug('MailParams', $hMailParams);

    my %Vars = (
        'JanolawUserID' => $Shop->get('JanolawUserID'),
        'JanolawShopID' => $Shop->get('JanolawShopID'),
        'JanolawMerchantExpiredLink' => BuildShopUrl($Shop, {'ViewAction' => 'MBO-ViewJanolawContent' }, {'Type' => 'admin' , 'UseSSL' => 1 }),
    );

    LogDebug('Vars', %Vars);

    my $Locale = $Shop->get('LocaleID');

    GetLog()->debug($Locale);

    my %RegionalParams = (
        'Locale'   => $Locale,
        'Language' => GetInfoLanguage( GetInfoLocale($Locale)->{'LanguageID'} )->{'Code2'},
    );

    LogDebug('RegionalParams', %RegionalParams);

    $MailType->send( $Shop, $hMailParams, \%RegionalParams, \%Vars );

    GetLog()->debug('send');

    return 1;
}

1;
