use strict;
use Getopt::Long;
use DE_EPAGES::Core::API::Script qw( RunScript );
use DE_EPAGES::Core::API::PerlTools qw (GetLocalTimeZone GetCurrentDateTime);
use DE_EPAGES::Database::API::Connection qw( RunOnStore );
use DE_EPAGES::Object::API::Factory qw (LoadRootObject);

sub Main {

    local $| = 1;

    my $Password;
    my $StoreName;
    my $Help;

    GetOptions(
        'help'          => \$Help,
        'passwd=s'      => \$Password,
        'storename=s'   => \$StoreName,
    );

    usage() if $Help;

    unless($StoreName) {
        print STDERR "Missing parameter -storename\n\n";
        usage();
    }

    RunOnStore(
        Store => $StoreName,
        DBPassword => $Password,
        Sub => sub  { testDateTime($StoreName) },
    );
}

sub testDateTime {
    my ($StoreName) = @_;
    my $ServerTimeZone = GetLocalTimeZone();
    my $ServerDateTime = GetCurrentDateTime();
    my $SystemTimeZone = LoadRootObject()->get('TimeZone');
    my $SystemDateTime = GetCurrentDateTime($SystemTimeZone);

    print "====================================\n";
    print "Server\n";
    print "------------------------------------\n";
    print "Server TimeZone: $ServerTimeZone\n";
    print "Server DateTime: $ServerDateTime\n";
    print "====================================\n";
    print "System: $StoreName\n";
    print "------------------------------------\n";
    print "System TimeZone: $SystemTimeZone\n";
    print "System DateTime: $SystemDateTime\n";
    print "====================================\n";
}

sub usage {
    print <<END_USAGE;
Usage:
    perl $0 [options] [flags] datafiles

options:
    -passwd     database user password              ()
    -storename  name of store                       ()
flags:
    -help       show the command line options

Example:
    perl $0 -storename Store
END_USAGE
    exit 2;
}

RunScript(
    'Sub' => \&Main
);

