use base DE_EPAGES::Core::API::Test;

use DE_EPAGES::Object::API::Factory          qw( LoadObject DeleteObjectAtCache );
use DE_EPAGES::Database::API::Connection;    # CURRENT_DBI
use DE_EPAGES::Object::API::Object::Class;   # _preLoad
use Test::More;                              # ok
use Time::HiRes                              qw( alarm );
use strict;

my $ID = 5;

sub init {
   change_connection_handler();

   _LoadObject($ID);   # Initialize cache

   use_cache_only();         # Go to run mode
}
sub test {
   ok _LoadObject($ID),   "LoadObject works with fix";

   import_broken_LoadObject();
   ok ! _LoadObject($ID), "LoadObject not working when not stored right away in cache";

   done_testing();
}

sub _LoadObject {
   my ($id) = @_;

   DeleteObjectAtCache($id);                 # Make sure object is not already in cache

   local $SIG{ALRM} =  sub{ die "alarm" };   # Timeout

   eval {
      alarm 0.1;                             # Should not take this long (seconds)
      LoadObject($id);
   };

   my $error = $@;
   alarm 0;                                  # Clear timer

   return not $error;
}
sub change_connection_handler {
   $DE_EPAGES::Database::API::Connection::CURRENT_DBI = bless {}, "My::Connection";
}
sub use_cache_only {
   $DE_EPAGES::Object::API::Factory::DO_CACHE = 0
}
sub import_broken_LoadObject {
   my $broken_sub = \&DE_EPAGES::Object::API::Factory::LoadObject_BROKEN;

   # Update LoadObject in: this package, Factory, and DALObject.
   # It is not enough to simply update (or mock) the original code in Factory.
   #
   # This is due to the fact that:
   #  1. There are at least 3 symbol tables that contain "LoadObject".
   #  2. Updating the original function (in Factory) does not automatically update
   #     that function in other symbol tables (like main or DALObject).
   #
   # use case:
   # perl -E 'sub A::func{say "old"} *B::func = \&A::func; *A::func = sub{say "new"}; A::func(); B::func(); say *A::func{CODE}; say *B::func{CODE}'
   *LoadObject                                            = $broken_sub; # Import LoadObject into this package (main)
   *DE_EPAGES::Object::API::Factory::LoadObject           = $broken_sub; # Import LoadObject into DE_EPAGES::Object::API::Factory
   *DE_EPAGES::Object::API::Object::DALObject::LoadObject = $broken_sub; # Import LoadObject into DE_EPAGES::Object::API::Object::DALObject
}


__PACKAGE__->runScript();


#--------------------------------------------------------------------------
#
# Package Mocks
#
# The below packages are mocked to avoid having to use the database
# as well as isolating the problem (a bit).
#
#--------------------------------------------------------------------------

## no critic (ProhibitMultiplePackages,ProhibitUnusedPrivateSubroutines)
package My::Connection;
sub cacheKey { "Sample" }

package DE_EPAGES::Object::API::Object::Class;
sub _preLoad {}

package DE_EPAGES::Database::API::DAL;
sub load { __PACKAGE__ }
sub info {
   {
      'Alias' => 'Class',
      'ClassID' => 5,
      'CreationDate' => '2019-07-01 13:00:22',
      'FilePathPart' => undef,
      'GUID' => '5D19E7C6-6284-B8BD-E69A-AC14327659CE',
      'Inherit' => 1,
      'ObjectID' => 5,
      'Package' => 'DE_EPAGES::Object::API::Object::Class',
      'ParentID' => 2,
      'Position' => 0,
      'SiteID' => 1,
   };
}

package DE_EPAGES::Object::API::Factory;

sub LoadObject_BROKEN($;$) {
   my $DAL_PACKAGE = 'DE_EPAGES::Database::API::DAL';
   my ($ObjectID, $DALPackage) = @_;
   Error('NoObjectID') unless defined $ObjectID;
    
   my $ObjectCache = GetObjectCache();
   my $Object = $ObjectCache->{$ObjectID};
   if(not defined $Object or $Object->{'Removed'} ) {
      $DALPackage //= $DAL_PACKAGE->load('DE_EPAGES::Object::API::Object::Object');
      my $hObject = $DALPackage->info( $ObjectID );
      Error( 'NoResults_ObjectID', { ObjectID => $ObjectID } ) unless defined $hObject;

      my $ClassID = $hObject->{'ClassID'};
      my $Class = $ObjectCache->{$ClassID};
      if (defined $Class) {
         $Object = $Class->loadObject( $ObjectID, 1 ); # 1 = load direct
      }
      else {
         my $hClass = $DAL_PACKAGE->load('DE_EPAGES::Object::API::Object::Class')->info($ClassID) or Error('NoClass', { ClassID=>$ClassID });
         my $Package = $hClass->{Package};
         UsePackage($Package);
         $Object = $Package->load( $ObjectID );

     ### $ObjectCache->{$ObjectID} = $Object;  ### Orignal code did not have this (bug fix) line

         $ObjectCache->{$ClassID} = $Object->class unless exists $ObjectCache->{$ClassID}; # could be now in
      }

      $ObjectCache->{$ObjectID} = $Object;
   }

   return $Object;
}

