#==============================================================================
# package      DE_EPAGES::Presentation::API::Constants
# state        public
# description  Constants for the Presentation cartridge
#==============================================================================
package DE_EPAGES::Presentation::API::Constants;
use base Exporter;

use strict;
use DE_EPAGES::Core::API::Constants qw (); # PASSWORD_DUMMY

our @EXPORT_OK = qw(
    $PROCESSMONITOR
    RESERVED_ATTRIBUTENAMES
    PASSWORD_DUMMY
    BASIC_JSON_ATTRIBUTES
    DEFAULT_HISTORY_ENTRIES
    MAX_PREVIEW_CHILD_ITEMS
    ALLOW_SESSION_IN_URL
    JQUERY_JSON_ATTRIBUTES
    JQUERY_JSON_IGNORED_CLASSES
    MAX_IMAGE_UPLOAD_SIZE
    UNITY_VIEW_ACTION_EXCEPTION_REGEX
    RECAPTCHA_PUBLIC_KEY
    RECAPTCHA_PRIVATE_KEY
    RECAPTCHA_CALL_TIMEOUT
    RECAPTCHA_CALL_URL
    RECAPTCHA_FORM_ERROR
    RECAPTCHA_TEST_KEY_HOSTNAME
    UNITY_SF_VIEW_ACTION_PREFIX
    WRITEABLE_PATH_ATTRIBUTES
);

use DE_EPAGES::Core::API::EpagesConfig qw( EpagesConfig );

#========================================================================================
# global       $PROCESSMONITOR | true if the monitor is enabled | boolean
# global       $DEFAULT_HISTORY_ENTRIES | count of history entries (20) | int
#========================================================================================
our $PROCESSMONITOR = 1;
use constant DEFAULT_HISTORY_ENTRIES => 20;

#========================================================================================
# global       RESERVED_ATTRIBUTENAMES | reserved names witch cannot be used as
#                   attribute names | array
#========================================================================================
use constant RESERVED_ATTRIBUTENAMES => qw (ChangeAction CurrencyID Language Locale
    ObjectID ObjectPath Price ShopID Style System Value ViewAction UnityAlias);

#========================================================================================
# global       PASSWORD_DUMMY | the dummy text which is displayed in password fields
#                   (********) | string
#========================================================================================
sub PASSWORD_DUMMY { ## no critic qw(RequireCommentForExportedFunctions)
    return DE_EPAGES::Core::API::Constants::PASSWORD_DUMMY;
}

#========================================================================================
# global       BASIC_JSON_ATTRIBUTES | deprecated only used by dojo json,
#                list of attributes names for JSONChildren
#               | ref.array.string
#========================================================================================
use constant BASIC_JSON_ATTRIBUTES => [qw(ObjectID Alias NameOrAlias ClassID Position WebUrl WebUrlSSL Path)];

#========================================================================================
# global       JQUERY_JSON_ATTRIBUTES | list of attributes names for JSONChildrenJSTree
#               | ref.array.string
#========================================================================================
use constant JQUERY_JSON_ATTRIBUTES => [qw(ClassID WebUrl WebUrlSSL)];

#========================================================================================
# global       JQUERY_JSON_IGNORED_CLASSES | list of ignored classed for JSONChildrenJSTree
#               | ref.array.string
#========================================================================================
use constant JQUERY_JSON_IGNORED_CLASSES => [qw(CustomForm ImageGallery GuestBook Forum BlogPost)];

#========================================================================================
# global       MAX_PREVIEW_CHILD_ITEMS | number of maximal visible child items | int
#========================================================================================
use constant MAX_PREVIEW_CHILD_ITEMS => 1000;


#========================================================================================
# global       MAX_IMAGE_UPLOAD_SIZE | max image size in kB for uploading images | int
#               The value of  MAXCONTENTLENGTH in WebInterface.conf is the max size
#               use this constant to set the limit lower than MAXCONTENTLENGTH
#========================================================================================
use constant MAX_IMAGE_UPLOAD_SIZE => undef;

#========================================================================================
# global       ALLOW_SESSION_IN_URL | Enables session handling for user agents that do
#               do accept cookies for all or some domains. Default=1.
#               This value is configurable in the epages.conf file, section
#               DE_EPAGES::Presentation, key AllowSessionInURL | integer
#========================================================================================
sub ALLOW_SESSION_IN_URL() { ## no critic qw(RequireCommentForExportedFunctions)
    return EpagesConfig()->get( 'DE_EPAGES::Presentation', 'AllowSessionInURL', 1 );
}

#========================================================================================
# global       UNITY_VIEW_ACTION_EXCEPTION_REGEX | regex list not to be prefixed with Unity | int
#========================================================================================
use constant UNITY_VIEW_ACTION_EXCEPTION_REGEX => qr/^(JSON|Unity|DereferredRedirect)/;


#========================================================================================
# global       RECAPTCHA_PUBLIC_KEY | returns ReCaptcha public key
#========================================================================================
sub RECAPTCHA_PUBLIC_KEY() { ## no critic qw(RequireCommentForExportedFunctions)
    return EpagesConfig()->get('GoogleCaptcha', 'ReCaptchaPublicKey');
}

#========================================================================================
# global       RECAPTCHA_PRIVATE_KEY | returns ReCaptcha private key
#========================================================================================
sub RECAPTCHA_PRIVATE_KEY() { ## no critic qw(RequireCommentForExportedFunctions)
    return EpagesConfig()->get('GoogleCaptcha', 'ReCaptchaPrivateKey');
}

#========================================================================================
# global       RECAPTCHA_CALL_TIMEOUT | Timeout for Google ReCaptcha API | int
#========================================================================================
use constant RECAPTCHA_CALL_TIMEOUT => 20;

#========================================================================================
# global       RECAPTCHA_CALL_URL | Google url | String
#========================================================================================
use constant RECAPTCHA_CALL_URL => 'https://www.google.com';

#========================================================================================
# global       RECAPTCHA_TEST_KEY_HOSTNAME | Google test key hostname response| String
#========================================================================================
use constant RECAPTCHA_TEST_KEY_HOSTNAME => 'testkey.google.com';

#========================================================================================
# global       RECAPTCHA_FORM_ERROR | Form error for Google ReCaptcha | hash
#========================================================================================
use constant RECAPTCHA_FORM_ERROR => {
        'Reason'=> 'RECAPTCHA_WRONG',
        'Form'  => 'CustomForm',
        'Name'  => 'Recaptcha',
};

#========================================================================================
# global       UNITY_SF_VIEW_ACTION_PREFIX | Prefix for SF view actions of an Unity shop
#                | string
#========================================================================================
use constant UNITY_SF_VIEW_ACTION_PREFIX => 'UnityView';

#========================================================================================
# global       WRITEABLE_PATH_ATTRIBUTES | List of attributes that are writable and
#               that are used to construct filenames. Must be checked because of potential
#               path traversal attacks | string
#========================================================================================
use constant WRITEABLE_PATH_ATTRIBUTES => [qw( FilePathPart UnityThemeStylePath )];

1;
