define("de_epages/spreedly/ui/checkoutlifecycle", [
    "jquery",
    "ep/fn/busy",
    "$ready!",
    "ep/ui/dialog",
], function ($) {

    return function(
        state,
        transaction_token,
        required_action,
        device_fingerprint_form,
        challenge_url,
        challenge_form,
        checkout_form,
        checkout_url,
        object_id,
        submitBasketForm,
        appendErrorAndSubmitBasketForm,
        SpreedlyEnvironmentKey
    ){
        var challengeDialog = undefined;

        var hiddenIframeDivId = "hiddenIframeDiv";
        var challengeIframeDivId = "challengeIframeDiv";

        var transactionData = {
            "state": state,
            "required_action": required_action,
            "device_fingerprint_form": device_fingerprint_form,
            "challenge_url": challenge_url,
            "challenge_form": challenge_form,
            "checkout_form": checkout_form,
            "checkout_url": checkout_url
        };

        var lifecycleParams = {
            "environmentKey":SpreedlyEnvironmentKey,
            "hiddenIframeLocation": hiddenIframeDivId,
            "challengeIframeLocation": challengeIframeDivId,
            "transactionToken": transaction_token,
            "challengeIframeClasses": "SpreedlyChallengeDialog FullWidth FullHeight"
        };

        function onSuccessTriggerCompletion(event, data) {
            if (data.state === 'succeeded') {
                submitBasketForm();
            }
            if (data.state === 'pending') {
                event.finalize(data);
            }
        }

        function showChallenge(event) {
            var screenWidth = (window.innerWidth > 0) ? window.innerWidth : screen.width;
            var dialogOverflow = screenWidth > 600 ? 'hidden': 'auto';
            challengeDialog = ep('<div id="challengeIframeDiv" class="FullWidth FullHeight" style="overflow:hidden" />')
                .append("<style>.uiDialogStyle .ui-dialog-titlebar {display:none}" +
                    ".uiDialogStyle { overflow: " + dialogOverflow + "; padding: 0; }" +
                    "</style>")
                .uiDialog({
                    "dialogClass": 'uiDialogStyle',
                    "modal": true,
                    "width": 537,
                    "height": 620
                });

                challengeDialog.uiDialog('open');
                ep("body").busy("hide");
        }

        function on3dsTriggerCompletion (event) {
            ep.ajax({
                data: {
                    ChangeAction: 'CompleteSpreedlyTransaction',
                    TransactionToken: transaction_token,
                    ObjectID: object_id
                },
                type: 'POST',
                dataType: 'json'
            }).done(function (response) {
                if(!response.Error && response.Transaction){
                    onSuccessTriggerCompletion(event, response.Transaction);
                } else {
                    appendErrorAndSubmitBasketForm(response.Error);
                }
            }).fail(function( response ){
                appendErrorAndSubmitBasketForm({
                    "Name": "Complete",
                    "Reason": "ConnectionError",
                });
            });
        }

        function on3dsStatusUpdate (event) {
            if (event.action === "succeeded") {
                if (challengeDialog !== undefined) {
                    challengeDialog.uiDialog("destroy");
                    challengeDialog.remove();
                    ep("body").busy("show");
                }
                submitBasketForm();
            } else if (event.action === "error") {
                appendErrorAndSubmitBasketForm({
                    "Name": "Complete",
                    "Reason": "CardDeclined",
                });
            } else if (event.action === "trigger-completion") {
                on3dsTriggerCompletion(event);
            } else if (event.action === "challenge") {
                showChallenge(event);
            }
        }

        var lifecycle = new Spreedly.ThreeDS.Lifecycle(lifecycleParams);
        Spreedly.on("3ds:status", on3dsStatusUpdate);
        lifecycle.start(transactionData);
    };
});
