#========================================================================================
# package      DE_EPAGES::Spreedly::t::unit::UI_BasketOrder
# base         DE_EPAGES::Core::API::Test
# state        public
#----------------------------------------------------------------------------------------
# description  unit test for UI::BasketOrder
#========================================================================================
package DE_EPAGES::Spreedly::t::unit::UI_BasketOrder;
use base DE_EPAGES::Core::API::Test;

use DE_EPAGES::Core::API::Error qw ( Error );
use DE_EPAGES::Spreedly::UI::BasketOrder;
use DE_EPAGES::Test::Mock::EpagesObject;
use DE_EPAGES::Test::Mock::Mockify qw ( GetParametersFromMockifyCall WasCalled );
use DE_EPAGES::Test::Mock::MockifyServlet;
use Test::Exception;
use Test::MockObject::Extends;
use Test::More;
use DE_EPAGES::Spreedly::API::Constants qw ( 
    PURCHASE_RESPONSE_STATE_SUCEEDED
    PURCHASE_RESPONSE_STATE_PENDING
    PURCHASE_RESPONSE_STATE_PROCESSING
    PAYMENT_STATUS_PAID
    PAYMENT_STATUS_FAILED
    PAYMENT_STATUS_PROCESSING
    FAILURE_MESSAGES );

use strict;

use constant PAYMENT_INFO_TOKEN => 'EWdi0wRvmXUX5pOqPgvhTUtV8g3';

sub test {
    my $self = shift;

    $self->_test_MakePurchase_SuccessfulTransaction_SuccessState();
    $self->_test_MakePurchase_SuccessfulTransaction_ErrorState();
    $self->_test_MakePurchase_SuccessfulTransaction_PendingState();
    $self->_test_MakePurchase_UnsuccessfulTransaction();
    $self->_test_MakePurchase_WithError();
    $self->_test_RetrievePaymentInfoToken();
    $self->_test_RetrievePaymentInfoToken_EmptyToken();
    $self->_test_SetSpreedlyPaymentError();
    $self->_test_ConfirmSuccessfulTransaction_SuccessfulTransaction_SuccessState();
    $self->_test_ConfirmSuccessfulTransaction_SuccessfulTransaction_ProcessingState();
    $self->_test_ConfirmSuccessfulTransaction_SuccessfulTransaction_ErrorState();

    done_testing();
}

#----------------------------------------------------------------------------------------
# Tests
#----------------------------------------------------------------------------------------
sub _test_ConfirmSuccessfulTransaction_SuccessfulTransaction_SuccessState {
    my $self        = shift;
    my $SubTestName = ( caller(0) )[3];

    my $MockedUIBasketOrder = $self->_buildUIBasketOrder_SuccessfulTransactionSuccessState();
    my $MockedServlet       = $self->_buildServlet();
    my $Basket = $MockedServlet->object();
    $MockedUIBasketOrder->ConfirmSuccessfulTransaction($MockedServlet, $Basket);

    my $LineItemContainer = $Basket->get('LineItemContainer');
    my $LineItemPaymentSpreedly = $LineItemContainer->get('Payment');

    is( $LineItemPaymentSpreedly->call_pos( 4 ), 'updateTransactionStatus', "$SubTestName - updateTransactionStatus has been called." );
    is( ($LineItemPaymentSpreedly->call_args( 4 ))[1], PAYMENT_STATUS_PAID, "$SubTestName - updateTransactionStatus has been called with correct arguments." );

    return;
}

sub _test_ConfirmSuccessfulTransaction_SuccessfulTransaction_ProcessingState {
    my $self        = shift;
    my $SubTestName = ( caller(0) )[3];

    my $MockedUIBasketOrder = $self->_buildUIBasketOrder_SuccessfulTransactionProcessingState();
    my $MockedServlet       = $self->_buildServlet();
    my $Basket = $MockedServlet->object();
    $MockedUIBasketOrder->ConfirmSuccessfulTransaction($MockedServlet, $Basket);

    my $LineItemContainer = $Basket->get('LineItemContainer');
    my $LineItemPaymentSpreedly = $LineItemContainer->get('Payment');

    is( $LineItemPaymentSpreedly->call_pos( 4 ), 'updateTransactionStatus', "$SubTestName - updateTransactionStatus has been called." );
    is( ($LineItemPaymentSpreedly->call_args( 4 ))[1], PAYMENT_STATUS_PROCESSING, "$SubTestName - updateTransactionStatus has been called with correct arguments." );

    return;
}

sub _test_ConfirmSuccessfulTransaction_SuccessfulTransaction_ErrorState {
    my $self        = shift;
    my $SubTestName = ( caller(0) )[3];

    my $MockedUIBasketOrder = $self->_buildUIBasketOrder_SuccessfulTransactionErrorState();
    my $MockedServlet       = $self->_buildServlet();
    my $Basket = $MockedServlet->object();
    $MockedUIBasketOrder->ConfirmSuccessfulTransaction($MockedServlet, $Basket);

    my $LineItemContainer = $Basket->get('LineItemContainer');
    my $LineItemPaymentSpreedly = $LineItemContainer->get('Payment');

    is( $LineItemPaymentSpreedly->called( 'updateTransactionStatus' ), 0, "$SubTestName - updateTransactionStatus has not been called." );

    return;
}

sub _test_MakePurchase_SuccessfulTransaction_SuccessState {
    my $self        = shift;
    my $SubTestName = ( caller(0) )[3];

    my $MockedUIBasketOrder = $self->_buildUIBasketOrder_SuccessfulTransactionSuccessState();
    my $MockedServlet       = $self->_buildServlet();
    $MockedUIBasketOrder->MobileMakePurchase($MockedServlet);

    ok( WasCalled( $MockedUIBasketOrder, '_createCustomerOrder' ), "$SubTestName - _createCustomerOrder has been called." );
    ok( WasCalled( $MockedUIBasketOrder, '_SaveTransactionNumber' ), "$SubTestName - _SaveTransactionNumber has been called." );
    ok( WasCalled( $MockedUIBasketOrder, '_SetOrderToPaid' ), "$SubTestName - _SetOrderToPaid has been called." );
    ok( WasCalled( $MockedUIBasketOrder, '_ShowCustomerOrder' ), "$SubTestName - _ShowCustomerOrder has been called." );

    return;
}

sub _test_MakePurchase_SuccessfulTransaction_PendingState {
    my $self        = shift;
    my $SubTestName = ( caller(0) )[3];

    my $MockedUIBasketOrder = $self->_buildUIBasketOrder_SuccessfulTransactionPendingState();
    my $MockedServlet       = $self->_buildServlet();
    $MockedUIBasketOrder->MobileMakePurchase($MockedServlet);

    ok( WasCalled( $MockedUIBasketOrder, '_createCustomerOrder' ), "$SubTestName - _createCustomerOrder has been called." );
    ok( WasCalled( $MockedUIBasketOrder, '_SetPaymentAsFailed' ), "$SubTestName - _SetPaymentAsFailed has been called." );
    ok( WasCalled( $MockedUIBasketOrder, '_ShowPaymentFailure' ), "$SubTestName - _ShowPaymentFailure has been called." );
    ok( !WasCalled( $MockedUIBasketOrder, '_SetOrderToPaid' ), "$SubTestName - _SetOrderToPaid has not been called." );

    my $ExpectedFailureParameters = [$MockedServlet, FAILURE_MESSAGES->{'Name'}->{'MobilePurchase'}, FAILURE_MESSAGES->{'Reason'}->{'CardDeclined'}];
    my $ActualFailureParameters = GetParametersFromMockifyCall($MockedUIBasketOrder, '_ShowPaymentFailure');
    is_deeply($ActualFailureParameters, $ExpectedFailureParameters ,"$SubTestName - _ShowPaymentFailure has correct parameters." );

    return;
}

sub _test_MakePurchase_SuccessfulTransaction_ErrorState {
    my $self        = shift;
    my $SubTestName = ( caller(0) )[3];

    my $MockedUIBasketOrder = $self->_buildUIBasketOrder_SuccessfulTransactionErrorState();
    my $MockedServlet       = $self->_buildServlet();
    $MockedUIBasketOrder->MobileMakePurchase($MockedServlet);

    ok( WasCalled( $MockedUIBasketOrder, '_createCustomerOrder' ), "$SubTestName - _createCustomerOrder has been called." );
    ok( WasCalled( $MockedUIBasketOrder, '_SetPaymentAsFailed' ), "$SubTestName - _SetPaymentAsFailed has been called." );
    ok( WasCalled( $MockedUIBasketOrder, '_ShowPaymentFailure' ), "$SubTestName - _ShowPaymentFailure has been called." );
    ok( !WasCalled( $MockedUIBasketOrder, '_SetOrderToPaid' ), "$SubTestName - _SetOrderToPaid has not been called." );

    my $ExpectedFailureParameters = [$MockedServlet, FAILURE_MESSAGES->{'Name'}->{'MobilePurchase'}, FAILURE_MESSAGES->{'Reason'}->{'ConnectionError'}];
    my $ActualFailureParameters = GetParametersFromMockifyCall($MockedUIBasketOrder, '_ShowPaymentFailure');
    is_deeply($ActualFailureParameters, $ExpectedFailureParameters ,"$SubTestName - _ShowPaymentFailure has correct parameters." );

    return;
}

sub _test_MakePurchase_UnsuccessfulTransaction {
    my $self        = shift;
    my $SubTestName = ( caller(0) )[3];

    my $MockedUIBasketOrder = $self->_buildUIBasketOrder_UnsuccessfulTransaction();
    my $MockedServlet       = $self->_buildServlet();
    $MockedUIBasketOrder->MobileMakePurchase($MockedServlet);

    ok( WasCalled( $MockedUIBasketOrder, '_createCustomerOrder' ), "$SubTestName - _createCustomerOrder has been called." );
    ok( WasCalled( $MockedUIBasketOrder, '_SetPaymentAsFailed' ), "$SubTestName - _SetPaymentAsFailed has been called." );
    ok( WasCalled( $MockedUIBasketOrder, '_ShowPaymentFailure' ), "$SubTestName - _ShowPaymentFailure has been called." );
    ok( !WasCalled( $MockedUIBasketOrder, '_SetOrderToPaid' ), "$SubTestName - _SetOrderToPaid has not been called." );

    my $ExpectedFailureParameters = [$MockedServlet, FAILURE_MESSAGES->{'Name'}->{'MobilePurchase'}, FAILURE_MESSAGES->{'Reason'}->{'CardDeclined'}];
    my $ActualFailureParameters = GetParametersFromMockifyCall($MockedUIBasketOrder, '_ShowPaymentFailure');
    is_deeply($ActualFailureParameters, $ExpectedFailureParameters ,"$SubTestName - _ShowPaymentFailure has correct parameters." );

    return;
}

sub _test_MakePurchase_WithError {
    my $self        = shift;
    my $SubTestName = ( caller(0) )[3];

    my $MockedUIBasketOrder = $self->_buildUIBasketOrder_WithError();
    my $MockedServlet       = $self->_buildServlet();

    lives_ok( sub { $MockedUIBasketOrder->MobileMakePurchase($MockedServlet); }, "$SubTestName - Threw a SpreedlyMakePurchaseError exception" );

    ok( !WasCalled( $MockedUIBasketOrder, '_SaveTransactionNumber' ), "$SubTestName - _SaveTransactionNumber has not been called." );
    ok( WasCalled( $MockedUIBasketOrder, '_HandleCriticalErrorOnPurchaseRequest' ), "$SubTestName - _HandleCriticalErrorOnPurchaseRequest has been called." );
    ok( WasCalled( $MockedUIBasketOrder, '_createCustomerOrder' ), "$SubTestName - _createCustomerOrder has been called." );
    ok( WasCalled( $MockedUIBasketOrder, '_SetPaymentAsFailed' ), "$SubTestName - _SetPaymentAsFailed has been called." );
    ok( !WasCalled( $MockedUIBasketOrder, '_SetOrderToPaid' ), "$SubTestName - _SetOrderToPaid has not been called." );

    return;
}

sub _test_RetrievePaymentInfoToken {
    my $self        = shift;
    my $SubTestName = ( caller(0) )[3];

    my $MockedUIBasketOrder = $self->_createUIBasketOrder();
    my $MockedServlet       = $self->_buildServlet();
    $MockedUIBasketOrder->RetrievePaymentInfoToken($MockedServlet);
    my $Servlet = @{ GetParametersFromMockifyCall( $MockedUIBasketOrder, 'RetrievePaymentInfoToken' ) }[0];
    my $GotPaymentInfoToken = $Servlet->params('payment_method_token');
    is( $GotPaymentInfoToken, PAYMENT_INFO_TOKEN, "$SubTestName - Obtained expected payment information token." );

    return;
}

sub _test_RetrievePaymentInfoToken_EmptyToken {
    my $self        = shift;
    my $SubTestName = ( caller(0) )[3];

    my $MockedUIBasketOrder = $self->_createUIBasketOrder();
    my $MockedServlet       = $self->_buildServlet_EmptyToken();
    throws_ok( sub { $MockedUIBasketOrder->RetrievePaymentInfoToken($MockedServlet); },
        qr/ConnectionError/, "$SubTestName - Threw a ConnectionError exception" );
    my $Servlet                  = @{ GetParametersFromMockifyCall( $MockedUIBasketOrder, 'RetrievePaymentInfoToken' ) }[0];
    my $GotPaymentInfoToken      = $Servlet->params('payment_method_token');
    my $ExpectedPaymentInfoToken = undef;
    is( $GotPaymentInfoToken, $ExpectedPaymentInfoToken, "$SubTestName - Payment information token is empty." );

    return;
}

sub _test_SetSpreedlyPaymentError {
    my $self        = shift;
    my $SubTestName = ( caller(0) )[3];

    my $MockedUIBasketOrder = $self->_buildUIBasketOrder_SuccessfulTransactionSuccessState();
    my $MockedServlet       = $self->_buildServlet();

    $MockedUIBasketOrder->_setSpreedlyPaymentError($MockedServlet, FAILURE_MESSAGES->{'Name'}->{'Purchase'}, FAILURE_MESSAGES->{'Reason'}->{'CardDeclined'});    ## no critic (ProhibitPrivateSubroutineUse)

    my $ExpectedFailureParameters = [$MockedServlet, FAILURE_MESSAGES->{'Name'}->{'Purchase'}, FAILURE_MESSAGES->{'Reason'}->{'UnknownError'}];
    my $ActualFailureParameters = GetParametersFromMockifyCall($MockedUIBasketOrder, '_ShowPaymentFailure');
    is_deeply($ActualFailureParameters, $ExpectedFailureParameters ,"$SubTestName - _ShowPaymentFailure has correct parameters." );

    $MockedUIBasketOrder->_setSpreedlyPaymentError($MockedServlet, $MockedServlet->vars('ErrorName', 'Weird Name'), $MockedServlet->vars('ErrorReason', 'Weird Reason'));    ## no critic (ProhibitPrivateSubroutineUse)

    $ExpectedFailureParameters = [$MockedServlet, FAILURE_MESSAGES->{'Name'}->{'Purchase'}, FAILURE_MESSAGES->{'Reason'}->{'UnknownError'}];
    $ActualFailureParameters = GetParametersFromMockifyCall($MockedUIBasketOrder, '_ShowPaymentFailure');
    is_deeply($ActualFailureParameters, $ExpectedFailureParameters ,"$SubTestName - _ShowPaymentFailure has correct overriden parameters." );

    return;
}

#----------------------------------------------------------------------------------------
# Helpers
#----------------------------------------------------------------------------------------
sub _buildServlet {
    my $self             = shift;
    my $PaymentInfoToken = PAYMENT_INFO_TOKEN;

    return $self->_createServlet($PaymentInfoToken);
}

sub _buildServlet_EmptyToken {
    my $self = shift;

    return $self->_createServlet();
}

sub _buildUIBasketOrder_SuccessfulTransactionSuccessState {
    my $self = shift;

    my $hReturnValues = {
        '_makePurchaseRequest' => {
            'successful'    => '1',
            'transactionNo' => '123434',
            'state' => PURCHASE_RESPONSE_STATE_SUCEEDED
        },
        '_showTransaction' => {
            'successful'    => '1',
            'transactionNo' => '123434',
            'state' => PURCHASE_RESPONSE_STATE_SUCEEDED
        },
        '_LogPayment'          => undef,
        '_GetPaymentInfoToken' => PAYMENT_INFO_TOKEN,
        '_createCustomerOrder' => $self->_buildCustomerOrder(),
    };

    my $ThrowsError = 0;

    return $self->_createUIBasketOrder( $hReturnValues, $ThrowsError );
}

sub _buildUIBasketOrder_SuccessfulTransactionPendingState {
    my $self = shift;

    my $hReturnValues = {
        '_makePurchase' => {
            'successful'    => '1',
            'transactionNo' => '123434',
            'state' => PURCHASE_RESPONSE_STATE_PENDING
        },
        '_LogPayment'          => undef,
        '_GetPaymentInfoToken' => PAYMENT_INFO_TOKEN,
    };

    my $ThrowsError = 0;

    return $self->_createUIBasketOrder( $hReturnValues, $ThrowsError );
}

sub _buildUIBasketOrder_SuccessfulTransactionProcessingState {
    my $self = shift;

    my $hReturnValues = {
        '_makePurchase' => {
            'successful'    => '1',
            'transactionNo' => '123434',
            'state' => PURCHASE_RESPONSE_STATE_PENDING
        },
        '_showTransaction' => {
            'successful'    => '1',
            'transactionNo' => '123434',
            'state' => PURCHASE_RESPONSE_STATE_PROCESSING
        },
        '_LogPayment'          => undef,
        '_GetPaymentInfoToken' => PAYMENT_INFO_TOKEN,
    };

    my $ThrowsError = 0;

    return $self->_createUIBasketOrder( $hReturnValues, $ThrowsError );
}


sub _buildUIBasketOrder_SuccessfulTransactionErrorState {
    my $self = shift;

    my $hReturnValues = {
        '_makePurchaseRequest' => {
            'successful'    => '1',
            'transactionNo' => '123434',
            'state' => 'ERROR'
        },
        '_showTransaction' => {
            'successful'    => '1',
            'transactionNo' => '123434',
            'state' => 'ERROR'
        },
        '_LogPayment'          => undef,
        '_GetPaymentInfoToken' => PAYMENT_INFO_TOKEN,
        '_createCustomerOrder' => $self->_buildCustomerOrder(),
    };

    my $ThrowsError = 0;

    return $self->_createUIBasketOrder( $hReturnValues, $ThrowsError );
}

sub _buildUIBasketOrder_UnsuccessfulTransaction {
    my $self = shift;

    my $hReturnValues = {
        '_makePurchaseRequest' => {
            'successful'    => '0',
            'transactionNo' => '123434',
        },
        '_showTransaction' => {
            'successful'    => '0',
            'transactionNo' => '123434',
        },
        '_LogPayment'          => undef,
        '_GetPaymentInfoToken' => PAYMENT_INFO_TOKEN,
        '_createCustomerOrder' => $self->_buildCustomerOrder(),
    };

    my $ThrowsError = 0;

    return $self->_createUIBasketOrder( $hReturnValues, $ThrowsError );
}

sub _buildUIBasketOrder_WithError {
    my $self = shift;

    my $hReturnValues = {
        '_makePurchaseRequest' => {
            'successful'    => '0',
            'transactionNo' => '123434',
        },
        '_LogPayment'          => undef,
        '_GetPaymentInfoToken' => PAYMENT_INFO_TOKEN,
        '_createCustomerOrder' => $self->_buildCustomerOrder(),
    };

    my $ThrowsError = 1;

    return $self->_createUIBasketOrder( $hReturnValues, $ThrowsError );
}

sub _buildCustomerOrder {
    my $self = shift;

    my $hParams = {
        'ID'          => '19999',
        'PaidOn'      => undef,
        'CancelledOn' => undef,
    };

    return $self->_createCustomerOrder($hParams);
}

sub _createUIBasketOrder {
    my $self = shift;
    my ( $hReturnValues, $ThrowsError ) = @_;

    my $Mockify = DE_EPAGES::Test::Mock::Mockify->new('DE_EPAGES::Spreedly::UI::BasketOrder');

    my $aLogPaymentParams = [ 'any', 'string', 'any' ];

    $Mockify->addMockWithReturnValueAndParameterCheck( '_LogPayment', $hReturnValues->{'_LogPayment'}, $aLogPaymentParams );

    $Mockify->addMock(
        '_makePurchaseRequest',
        sub {
            shift;
            if ($ThrowsError) {
                Error('ConnectionError');
            }

            return $hReturnValues->{'_makePurchaseRequest'};
        }
    );
    $Mockify->addMock(
        '_showTransaction',
        sub {
            shift;
            if ($ThrowsError) {
                Error('ConnectionError');
            }

            return $hReturnValues->{'_showTransaction'};
        }
    );
    my $aRetrieveLineItemPaymentParams = [ { 'object' => 'DE_EPAGES::Order::API::Object::Basket' } ];
    my $aRetrieveLineItemPaymentReturn = [ { 'object' => 'DE_EPAGES::Spreedly::API::Object::LineItemPaymentSpreedly' } ];
    $Mockify->addMockWithReturnValueAndParameterCheck( '_RetrieveLineItemPayment', $aRetrieveLineItemPaymentReturn, $aRetrieveLineItemPaymentParams );

    my $aPaymentInformationControllerParams = [ 'any', 'string' ];
    $Mockify->addMockWithReturnValueAndParameterCheck( '_StoreTokenFromController', undef, $aPaymentInformationControllerParams );

    my $aShowCustomerOrderParams = [ 'object', 'object' ];
    $Mockify->addMockWithReturnValueAndParameterCheck( '_ShowCustomerOrder', undef, $aShowCustomerOrderParams );

    my $aShowPaymentFailureParams = [ 'object', 'string', 'string' ];
    $Mockify->addMockWithReturnValueAndParameterCheck( '_ShowPaymentFailure', undef, $aShowPaymentFailureParams );

    $Mockify->addMockWithReturnValueAndParameterCheck( '_HandleCriticalErrorOnPurchaseRequest', undef, ['object', 'object'] );
    $Mockify->addMockWithReturnValueAndParameterCheck( '_createCustomerOrder', $self->_createCustomerOrder(), ['object', 'object'] );

    $Mockify->addMockWithReturnValueAndParameterCheck( '_SetOrderToPaid', 0, ['object'] );

    $Mockify->addMethodSpyWithParameterCheck( 'RetrievePaymentInfoToken', ['object'] );
    $Mockify->addMethodSpyWithParameterCheck( '_SaveTransactionNumber',   [ 'hashref', 'object' ] );
    $Mockify->addMethodSpyWithParameterCheck( '_SetPaymentAsFailed',      [ 'object' ] );
    $Mockify->addMethodSpyWithParameterCheck( '_ShowCustomerOrder',      [ 'object', 'object' ] );

    return $Mockify->getMockObject();
}

sub _createBasket {
    my $self        = shift;
    my $hAttributes = {
        'Site'              => undef,
        'LineItemContainer' => $self->_createLineItemContainer(),
        'GUID'              => '56D5521B-08D3-2F44-728A-7F0001012E94',
    };

    my $Basket = DE_EPAGES::Test::Mock::EpagesObject->new( 'DE_EPAGES::Order::API::Object::Basket', $hAttributes );

    return $Basket;
}

sub _createCustomerOrder {
    my $self = shift;
    my ($hParams) = @_;

    my $hAtributes = {
        'PaidOn'            => $hParams->{'PaidOn'},
        'CancelledOn'       => $hParams->{'CancelledOn'},
        'LineItemContainer' => $self->_createLineItemContainer(),
        'ID' => 123,
    };
    my $CustomerOrder = DE_EPAGES::Test::Mock::EpagesObject->new( 'DE_EPAGES::Order::API::Object::CustomerOrder', $hAtributes );

    return $CustomerOrder;
}

sub _createForm {
    my $self = shift;

    my $MockedForm = DE_EPAGES::Test::Mock::EpagesObject->new('DE_EPAGES::WebInterface::API::Form');

    $MockedForm->mock(
        'executeFormError',
        sub {
            shift;
            my ($hFormError) = @_;

            my $ErrorReason = $hFormError->{'Reason'};
            Error($ErrorReason);

            return;
        }
    );

    $MockedForm->mock(
        'value',
        sub {
            shift;

            return 'ViewMultiCheckoutPayment';
        }
    );

    return $MockedForm;
}

sub _createLineItemContainer {
    my $self = shift;

    my $hAttributes = {
        'GrandTotal' => '80',
        'CurrencyID' => 'GBP',
        'Payment'    => $self->_createLineItemPayment(),
    };

    my $MockedLineItemContainer = DE_EPAGES::Test::Mock::EpagesObject->new( 'DE_EPAGES::Order::API::Object::LineItemContainer', $hAttributes );

    return $MockedLineItemContainer;
}

sub _createLineItemPayment {
    my $self = shift;

    my $hAttributes = { 'TransTime' => 'Feb 23, 2015 11:44:41 AM', };
    my $MockedLineItemPayment = DE_EPAGES::Test::Mock::EpagesObject->new( 'DE_EPAGES::Spreedly::API::Object::LineItemPaymentSpreedly', $hAttributes );
    $MockedLineItemPayment->mock(
        'updateTransactionStatus',
        sub {
            return;
        }
    );
    $MockedLineItemPayment->mock(
        'updateOnExecute',
        sub {
            return;
        }
    );
    $MockedLineItemPayment->mock(
        'getTransactionToken',
        sub {
            return PAYMENT_INFO_TOKEN;
        }
    );
    $MockedLineItemPayment->mock(
        'isPaymentSuccessful',
        sub {
            return 0;
        }
    );
    $MockedLineItemPayment->mock(
        'isPaymentProcessing',
        sub {
            return 0;
        }
    );
    $MockedLineItemPayment->mock(
        'getPaymentStatusFromTransactionState',
        sub {
            my $self = shift;
            my ( $TransactionState ) = @_;
            if ($TransactionState eq PURCHASE_RESPONSE_STATE_SUCEEDED) {
                return PAYMENT_STATUS_PAID;
            }
            if ($TransactionState eq PURCHASE_RESPONSE_STATE_PROCESSING) {
                return PAYMENT_STATUS_PROCESSING;
            }
            return PAYMENT_STATUS_FAILED;
        }
    );

    return $MockedLineItemPayment;
}

sub _createServlet {
    my $self = shift;
    my ($PaymentInfoToken) = @_;

    my $Basket         = $self->_createBasket();
    my $MockifyServlet = DE_EPAGES::Test::Mock::MockifyServlet->new($Basket);
    $MockifyServlet->addMockWithReturnValue( 'form', $self->_createForm() );
    $MockifyServlet->addParam( 'payment_method_token', $PaymentInfoToken );
    

    return $MockifyServlet->getMockObject();
}

__PACKAGE__->runScript();

1;
