use strict;
use feature 'say';
use DE_EPAGES::Core::API::Script qw ( RunScript );
use DE_EPAGES::TaxUSSystemDB::API::Zip2TaxUS qw (
    ImportZip2TaxUSTable
    UpdateZip2TaxUSTable
);
use Getopt::Long;


sub Main {
    local $| = 1;

    my $FileName;
    my $Help;
    my $NoOutput;

    GetOptions(
        'help'               => \$Help,
        'append-from-file=s' => \$FileName,
        'nooutput'           => \$NoOutput
    );

    usage() if $Help;

    my $time1 = time;

    if (defined $FileName) {
        Append($FileName);
    }
    else {
        Update($NoOutput);
    }

    printf "need %.3f seconds\n", time - $time1 unless $NoOutput;
}

sub Update {
    my ($NoOutput) = @_;

    say 'Update zip2taxus table, please be patient ...' unless $NoOutput;
    my $Message = UpdateZip2TaxUSTable();
    say $Message if defined $Message and not $NoOutput;

    say 'Done' unless $NoOutput;
}

sub Append {
    my ($FileName) = @_;

    die "File '$FileName' not found" unless (-f $FileName);

    say "Append zip2taxus table from file $FileName";
    ImportZip2TaxUSTable($FileName);
}

sub usage {
    print <<END_USAGE;
Usage:
    perl $0 [options] flags objects

options:
    -passwd            database user password         ()
    -append-from-file  local csv file containing
                       zip2tax-style tax information  (optional)
flags:
    -help              show the command line options

Example:
    perl $0
    perl $0 -append-from-file test.csv
END_USAGE
    exit 2;
}

RunScript(
    'Sub' => \&Main,
);
